@@ -182,7 +182,22 @@ class ApiGatewayToKinesisStreams(
         :summary: Constructs a new instance of the ApiGatewayToKinesisStreams class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ApiGatewayToKinesisStreams.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+                kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                put_record_request_model: typing.Optional[typing.Union[aws_cdk.aws_apigateway.ModelOptions, typing.Dict[str, typing.Any]]] = None,
+                put_record_request_template: typing.Optional[builtins.str] = None,
+                put_records_request_model: typing.Optional[typing.Union[aws_cdk.aws_apigateway.ModelOptions, typing.Dict[str, typing.Any]]] = None,
+                put_records_request_template: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToKinesisStreamsProps(
@@ -285,7 +300,20 @@ class ApiGatewayToKinesisStreamsProps:
         if isinstance(put_records_request_model, dict):
             put_records_request_model = aws_cdk.aws_apigateway.ModelOptions(**put_records_request_model)
         if __debug__:
-            type_hints = typing.get_type_hints(ApiGatewayToKinesisStreamsProps.__init__)
+            def stub(
+                *,
+                api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+                kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                put_record_request_model: typing.Optional[typing.Union[aws_cdk.aws_apigateway.ModelOptions, typing.Dict[str, typing.Any]]] = None,
+                put_record_request_template: typing.Optional[builtins.str] = None,
+                put_records_request_model: typing.Optional[typing.Union[aws_cdk.aws_apigateway.ModelOptions, typing.Dict[str, typing.Any]]] = None,
+                put_records_request_template: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
             check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
             check_type(argname="argument existing_stream_obj", value=existing_stream_obj, expected_type=type_hints["existing_stream_obj"])
